@@ -203,9 +203,13 @@ class PW:
 
         return p, r
 
+    # Tube proxy method
+
     def __getattr__(self, name: str) -> Any:
         """
         Proxy all unknown attributes to the local tube.
+
+        :param name: The name of the attribute to proxy.
         """
         if hasattr(self, name):
             return getattr(self, name)
@@ -218,3 +222,48 @@ class PW:
         raise AttributeError(
             f"{name} is not a valid attribute of this class or its tube!"
         )
+
+    # Convenience methods
+
+    def precvall(self) -> bytes:
+        """
+        Receive all data from the remote tube and print it.
+
+        :return: All data received from the remote tube.
+        """
+        b = self.recvall()
+        print(b)
+        return b
+
+    def precvline(self) -> bytes:
+        """
+        Receive a line from the remote tube and print it.
+
+        :return: A line received from the remote tube.
+        """
+        b: bytes = self.recvline()
+        print(b)
+        return b
+
+    def precv(self, numb: int) -> bytes:
+        """
+        Receive n bytes from the remote tube and print it.
+
+        :param numb: The number of bytes to receive.
+        :return: The n bytes received from the remote tube.
+        """
+        b: bytes = self.recvn(numb)
+        print(b)
+        return b
+
+    def precvuntil(self, delim: str, drop: bool = True) -> bytes:
+        """
+        Receive data from the remote tube until the delimiter is found.
+
+        :param delim: The delimiter to use.
+        :param drop: Whether to drop the delimiter.
+        :return: The data received from the remote tube.
+        """
+        b = self.recvuntil(delim, drop=drop)
+        print(b)
+        return b
